# SPDX-License-Identifier: CC0-1.0

{ nixpkgs, dhallApps, packages }:

rec {

  linux-image =
    let drv = import ./linux-image { inherit nixpkgs dhallApps packages; };
    in {
      type = "app";
      program = "${drv}/bin/linux-image";
    };

  generate-manifest = let
    drv = import ./generate-manifest {
      stdenv = packages.stdenv;
      inherit nixpkgs dhallApps;
    };
  in {
    type = "app";
    program = "${drv}/bin/generate-manifest";
  };

  hw-image = let
    drv = import ./hw-image {
      stdenv = packages.stdenv;
      inherit nixpkgs dhallApps packages;
    };
  in {
    type = "app";
    program = "${drv}/bin/hw-image";
    function = attrs: bootDesc:
      nixpkgs.runCommand "image.elf" attrs
      ''XDG_CACHE_HOME=$TMPDIR ${drv}/bin/hw-image "${bootDesc}" > $out'';
  };

  nova-image = let
    drv = import ./nova-image {
      stdenv = packages.stdenv;
      inherit nixpkgs dhallApps packages;
    };
  in {
    type = "app";
    program = "${drv}/bin/nova-image";
    function = attrs: bootDesc:
      nixpkgs.runCommand "image.elf" attrs
      ''XDG_CACHE_HOME=$TMPDIR ${drv}/bin/nova-image "${bootDesc}" > $out'';
  };

  hw-iso = let
    drv = import ./hw-iso {
      stdenv = packages.stdenv;
      inherit nixpkgs packages hw-image;
    };
  in {
    type = "app";
    program = "${drv}/bin/hw-iso";
    function = attrs: bootDesc:
      nixpkgs.runCommand "hw.iso" attrs
      ''XDG_CACHE_HOME=$TMPDIR ${drv}/bin/hw-iso "${bootDesc}" > $out'';
  };

  nova-iso = let
    drv = import ./nova-iso {
      stdenv = packages.stdenv;
      inherit nixpkgs packages nova-image;
    };
  in {
    type = "app";
    program = "${drv}/bin/nova-iso";
    function = attrs: bootDesc:
      nixpkgs.runCommand "nova.iso" attrs
      ''XDG_CACHE_HOME=$TMPDIR ${drv}/bin/nova-iso "${bootDesc}" > $out'';
  };

  render-init =
    let drv = import ./render-init { inherit nixpkgs dhallApps packages; };
    in {
      type = "app";
      program = "${drv}/bin/render-init";
    };

}
